==> qtjambi-quick-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiQuick/QSGRootNode_shell.cpp <==
#include "QSGRootNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGRootNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGRootNode")
    QSGRootNode *_ptr = reinterpret_cast<QSGRootNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGRootNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGRootNode_shell) ); }

jmethodID QSGRootNode_shell::__shell_javaMethod(int pos) const { return QSGRootNode_shell::__shell()->javaMethod(typeid(QSGRootNode), pos); }

// emitting (writeShellConstructor)
QSGRootNode_shell::QSGRootNode_shell()
    : QSGRootNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGRootNode::QSGRootNode_shell()", QSGRootNode_shell::__shell())
    QSGRootNode_shell::__shell()->constructed(typeid(QSGRootNode));
}

// emitting (writeShellDestructor)
QSGRootNode_shell::~QSGRootNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGRootNode::~QSGRootNode()", QSGRootNode_shell::__shell())
    QSGRootNode_shell::__shell()->destructed(typeid(QSGRootNode));
}

void QSGRootNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGRootNode_shell*>(ptr)->QSGRootNode_shell::__shell()->tryDeleteShell(typeid(QSGRootNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGRootNode_shell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGRootNode::", QSGRootNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGRootNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGRootNode_shell::__shell()->warnForMethod("QSGRootNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGRootNode::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGRootNode_shell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGRootNode::", QSGRootNode_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGRootNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGRootNode_shell::__shell()->warnForMethod("QSGRootNode::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGRootNode::");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGRootNode()
void __qt_construct_QSGRootNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGRootNode()")
    Q_UNUSED(__java_arguments)
    QSGRootNode *__qt_this = new(__qtjambi_ptr) QSGRootNode_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGRootNode::QSGRootNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGRootNode_initialize_1native__Lio_qt_quick_QSGRootNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGRootNode::QSGRootNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGRootNode, sizeof(QSGRootNode_shell), typeid(QSGRootNode), true, &deleter_QSGRootNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGRootNode_shell
void __qt_destruct_QSGRootNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGRootNode")
    reinterpret_cast<QSGRootNode_shell*>(ptr)->~QSGRootNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGRootNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGRootNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGRootNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGRootNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGRootNode>("QSGRootNode", "io/qt/quick/QSGRootNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGRootNode, {
        ConstructorInfo(&__qt_construct_QSGRootNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGRootNode);
    registerSizeOfShell(typeId, sizeof(QSGRootNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGRootNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QSGRootNode_shell.cpp <==
#include "QSGRootNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGRootNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGRootNode")
    QSGRootNode *_ptr = reinterpret_cast<QSGRootNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGRootNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGRootNode_shell) ); }

jmethodID QSGRootNode_oshell::__shell_javaMethod(int pos) const { return QSGRootNode_shell::__shell()->javaMethod(typeid(QSGRootNode), pos); }

// emitting (writeShellDestructor)
QSGRootNode_shell::~QSGRootNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGRootNode::~QSGRootNode()", this)
    QSGRootNode_shell::__shell()->destructed(typeid(QSGRootNode));
}

// emitting (writeShellConstructor)
QSGRootNode_shell::QSGRootNode_shell()
    : QSGRootNode()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGRootNode::QSGRootNode_shell()", this)
    QSGRootNode_shell::__shell()->constructed(typeid(QSGRootNode));
}

void QSGRootNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGRootNode_shell*>(ptr)->QSGRootNode_shell::__shell()->tryDeleteShell(typeid(QSGRootNode));
}

void QSGRootNode_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGRootNode_oshell*>(ptr)->QSGRootNode_oshell::__shell()->tryDeleteShell(typeid(QSGRootNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGRootNode_oshell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGRootNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGRootNode_shell::__shell()->warnForMethod("QSGRootNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGRootNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGRootNode_oshell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QSGRootNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QSGRootNode_shell::__shell()->warnForMethod("QSGRootNode::preprocess()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGRootNode::preprocess()");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSGRootNode()
void __qt_construct_QSGRootNode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGRootNode()")
    Q_UNUSED(__java_arguments)
    QSGRootNode *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QSGRootNode_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QSGRootNode_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSGRootNode::QSGRootNode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGRootNode_initialize_1native__Lio_qt_quick_QSGRootNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGRootNode::QSGRootNode()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGRootNode, sizeof(QSGRootNode_shell), typeid(QSGRootNode), 0, true, &deleter_QSGRootNode, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGRootNode_shell
void __qt_destruct_QSGRootNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGRootNode")
    reinterpret_cast<QSGRootNode_shell*>(ptr)->~QSGRootNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGRootNode_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QSGRootNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGRootNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGRootNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGRootNode>("QSGRootNode", "io/qt/quick/QSGRootNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGRootNode, {
        ConstructorInfo(&__qt_construct_QSGRootNode, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGRootNode);
    registerSizeOfShell(typeId, sizeof(QSGRootNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGRootNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
